@@ -21,6 +21,7 @@ from AnyQt.QtCore import (
     Signal)
 
 from .. import config
+from ..utils.localization import get_languages
 from ..utils.settings import SettingChangedEvent
 from ..utils.propertybindings import (
     AbstractBoundProperty, PropertyBinding, BindingManager
@@ -274,6 +275,25 @@ class UserSettingsDialog(QMainWindow):
         form = FormLayout()
         tab.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
 
+        languages = get_languages()
+        if languages:
+            langlay = QHBoxLayout()
+            label = QLabel(
+                "Changes will take effect on next application startup.")
+            label.setHidden(True)
+
+            cm_lang = QComboBox(
+                objectName="combo-language",
+                toolTip=self.tr("Select the application language.")
+            )
+            cm_lang.addItems(list(languages))
+            self.bind(cm_lang, "currentText", "application/language")
+            cm_lang.currentTextChanged.connect(lambda: label.setHidden(False))
+
+            langlay.addWidget(cm_lang)
+            langlay.addWidget(label)
+            form.addRow(self.tr("Language"), langlay)
+
         nodes = QWidget(self, objectName="nodes")
         nodes.setLayout(QVBoxLayout())
         nodes.layout().setContentsMargins(0, 0, 0, 0)
